@@ -1,8 +1,10 @@
 from django.test import TestCase
-from formwizard.storage import get_storage, MissingStorageModuleException, \
-                               MissingStorageClassException
+
+from formwizard.storage import (get_storage,
+    MissingStorageModule, MissingStorageClass)
 from formwizard.storage.base import BaseStorage
 
+
 class TestLoadStorage(TestCase):
     def test_load_storage(self):
         self.assertEqual(
@@ -10,9 +12,9 @@ class TestLoadStorage(TestCase):
             BaseStorage)
 
     def test_missing_module(self):
-        self.assertRaises(MissingStorageModuleException, get_storage, 
+        self.assertRaises(MissingStorageModule, get_storage,
             'formwizard.storage.idontexist.IDontExistStorage', 'wizard1')
 
     def test_missing_class(self):
-        self.assertRaises(MissingStorageClassException, get_storage, 
+        self.assertRaises(MissingStorageClass, get_storage,
             'formwizard.storage.base.IDontExistStorage', 'wizard1')
