@@ -1,17 +1,17 @@
 from django.conf.urls.defaults import *
-from formwizard.tests.namedwizardtests.forms import ContactWizard, Page1, Page2, Page3, Page4
+from formwizard.tests.namedwizardtests.forms import (
+    SessionContactWizard, CookieContactWizard, Page1, Page2, Page3, Page4)
+
 
 def get_named_session_wizard():
-    return ContactWizard(
-        'formwizard.storage.session.SessionStorage',
+    return SessionContactWizard.as_view(
         [('form1', Page1), ('form2', Page2), ('form3', Page3), ('form4', Page4)],
         url_name='nwiz_session',
         done_step_name='nwiz_session_done'
     )
 
 def get_named_cookie_wizard():
-    return ContactWizard(
-        'formwizard.storage.cookie.CookieStorage',
+    return CookieContactWizard.as_view(
         [('form1', Page1), ('form2', Page2), ('form3', Page3), ('form4', Page4)],
         url_name='nwiz_cookie',
         done_step_name='nwiz_cookie_done'
